home

package module
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 5, 2025 License: MIT Imports: 2 Imported by: 0

README

# home

Functions dealing with user home directories, getting them and
displaying paths with the absolute path replaced with "~".

## license

MIT

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func MustHome

func MustHome() string

MustHome is a version of os.UserHomeDir that panics.

func Replace

func Replace(s string) string

Replace replaces the user's home directory with "~".

func ReplaceViaTrimPrefix

func ReplaceViaTrimPrefix(s string) string

Types

This section is empty.

Jump to